##  Use Subscriptions to Assign Application Owners
If you know which users to assign as application owners, you can add fact sheet subscriptions in one of the following ways:
  * Add subscriptions using inline editing
  * Add subscriptions using Excel import
  * Add subscriptions to a single fact sheet


### Add Subscriptions Using Inline Editing
You can add subscriptions to multiple fact sheets using inline editing in the inventory table view. For more details, see [Subscribing and Unsubscribing in Bulk](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a16427a441014be448690c54e7cf0__subscribing_and_unsubscribing_in_bulk).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio118b34a0cd674b28bb7af797c42d0173_LowRes.png)
Adding Subscriptions Using Inline Editing in the Inventory
### Add Subscriptions Using Excel Import
You can add multiple subscriptions at once by importing data through Excel spreadsheets. For details, see [Subscriptions](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a86917a441014872eecad909f5e9e__subscriptions).
### Add Subscriptions to a Single Fact Sheet
Assign subscribers manually from the fact sheet page. Use this method if you already know who you want to assign to which fact sheets.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio41a0c612832a40e9b6d6f5b6162a33d0_LowRes.png)
Adding Subscriptions to a Single Fact Sheet
